"""
Django settings for haltools project.

Generated by 'django-admin startproject' using Django 1.11.20.

For more information on this file, see
https://docs.djangoproject.com/en/1.11/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.11/ref/settings/
"""

import os

import os

# pour binder sur le LDAP : django-auth-ldap et python-ldap
from django_auth_ldap.config import LDAPSearch, LDAPSearchUnion, GroupOfNamesType, ActiveDirectoryGroupType, NestedActiveDirectoryGroupType, NestedGroupOfNamesType, ActiveDirectoryGroupType
import ldap

# 1 - configuration pour l'utilisateur LDAP cherchant dans l'AD 192.168.100.75 = Samantha
AUTH_LDAP_SERVER_URI = "ldap://********"#"ldap://192.168.100.75:389"
AUTH_LDAP_BIND_DN = "cn=silimos,ou=Comptes de Services,dc=local,dc=isima,dc=fr"
AUTH_LDAP_BIND_PASSWORD = '*******'
AUTH_LDAP_CONNECTION_OPTIONS = {
    ldap.OPT_REFERRALS: 0
}

# sur tony chercher dans IQ0C, IT0C, JA0L et JB0L mais ces OU comprennent aussi d autres personnes ne devant pas se connecter normalement
AUTH_LDAP_USER_SEARCH = LDAPSearch("dc=local,dc=isima,dc=fr", ldap.SCOPE_SUBTREE, "(samAccountName=%(user)s)")
#AUTH_LDAP_USER_SEARCH = LDAPSearch("ou=uca,ou=Personnel,ou=Utilisateurs,dc=local,dc=isima,dc=fr", ldap.SCOPE_SUBTREE, "(samAccountName=%(user)s)")

# Set up the basic group parameters.
# Ici, on veut le groupe limos_personnel ainsi que les groupes imbriques (nested) comme limos_externe
AUTH_LDAP_GROUP_SEARCH = LDAPSearch("dc=local,dc=isima,dc=fr",
    ldap.SCOPE_SUBTREE, "(objectClass=group)"
)
AUTH_LDAP_GROUP_TYPE = NestedActiveDirectoryGroupType()

#AUTH_LDAP_REQUIRE_GROUP = "cn=labo_total,ou=LABO,ou=GROUPES_LOCAUX,dc=local,dc=isima,dc=fr"
AUTH_LDAP_REQUIRE_GROUP = "CN=srv_grp_intranet_limos,OU=SERVICES,OU=GROUPES_LOCAUX,DC=local,DC=isima,DC=fr"

# 3 - Liste des infos renvoyees
AUTH_LDAP_USER_ATTR_MAP = {"first_name": "givenName", "last_name": "sn",\
 "email": "mail", "login": "sAMAccountName", "dname":"distinguishedName"}

# 4 - Moyen d'authentification, si le LDAP n'est pas accessible, on bascule sur la table auth_user
AUTHENTICATION_BACKENDS = ('django_auth_ldap.backend.LDAPBackend', \
'django.contrib.auth.backends.ModelBackend',)


# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.11/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = '********************************'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

ALLOWED_HOSTS = ['localhost','127.0.0.1','haltools.limos.fr','192.168.79.38']

WSGI_APPLICATION = 'haltools.wsgi.application'

MEDIA_ROOT = os.path.join(BASE_DIR, 'media/')
MEDIA_URL = '/media/'

# 2 - Static files (CSS, JavaScript, Images)
STATIC_ROOT = os.path.join(BASE_DIR, 'static/')
STATIC_URL = '/static/'
STATICFILES_DIRS = (
    os.path.join(BASE_DIR, "staticfiles"),
)

JS_URL = '/js/'
JS_ROOT = os.path.join(BASE_DIR, 'js')

CSS_URL = '/css/'
CSS_ROOT = os.path.join(BASE_DIR, 'css')

FONTS_URL = '/fonts/'
FONTS_ROOT = os.path.join(BASE_DIR, 'fonts')


# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'bootstrap3',
    'bootstrap_themes',
    'hal',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'haltools.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'haltools.wsgi.application'


# Database
# https://docs.djangoproject.com/en/1.11/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'OPTIONS' : {"init_command": "SET foreign_key_checks = 0;"},
        'NAME': 'haltools',
        'USER': 'haladmin',
        'PASSWORD': '***********',
        'HOST': '127.0.0.1',
        'PORT': '',
    }
}

# Password validation
# https://docs.djangoproject.com/en/1.11/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


###################################################
'''
Infos de config pour envoi mails
'''
EMAIL_BACKEND = 'django.core.mail.backends.smtp.EmailBackend'

EMAIL_USE_TLS = True
EMAIL_HOST = 'mail.isima.fr'
EMAIL_PORT = 587
EMAIL_HOST_USER = 'cribot@isima.fr'# 'cri-commun@isima.fr'
EMAIL_HOST_PASSWORD = '****************'
DEFAULT_FROM_EMAIL = EMAIL_HOST_USER

# Celery Configuration Options
CELERYD_NODES="w1 w2"
CELERY_BROKER_URL = "amqp://halrabbuser:*************@localhost:5672//"
CELERY_TIMEZONE = "UTC"
CELERY_TASK_TRACK_STARTED = True

# Internationalization
# https://docs.djangoproject.com/en/1.11/topics/i18n/

LANGUAGE_CODE = 'en-us'
TIME_ZONE = 'UTC'
USE_I18N = True
USE_L10N = True
USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.11/howto/static-files/

STATIC_URL = '/static/'
